Machine
-------

A Machine is the central unity of
a model, dataset, metadata and everything
needed to create and build a ML model to
be served by a deployment.

.. automodule:: gordo.machine.machine.Machine
    :members:
    :undoc-members:
    :show-inheritance:

Model
=====

.. toctree::
    :maxdepth: 4
    :caption: Model

    ./model/model.rst

Dataset
=======

.. toctree::
    :maxdepth: 4
    :caption: Dataset

    ./dataset.rst

